Alert class

Constructors

Alert({String? title, String? body})
Alert.fromJson(Map<String, dynamic> json)
factory
Alert.fromRawJson(String str)
factory

Properties

body String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

copyWith({String? title, String? body}) Alert
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited