Android class

Constructors

Android({AndroidPriority? priority, double? secondsToShow, AndroidNotification? notification, AndroidFcmOptions? fcmOptions})
Android.fromJson(Map<String, dynamic> json)
factory
Android.fromRawJson(String str)
factory

Properties

fcmOptions AndroidFcmOptions?
final
hashCode int
The hash code for this object.
no setterinherited
notification AndroidNotification?
final
priority AndroidPriority?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondsToShow double?
final

Methods

copyWith({AndroidPriority? priority, double? secondsToShow, AndroidNotification? notification, AndroidFcmOptions? fcmOptions}) Android
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited