AndroidFcmOptions class
Constructors
- AndroidFcmOptions({String? analyticsLabel})
-
AndroidFcmOptions.fromJson(Map<
String, dynamic> json) -
factory
- AndroidFcmOptions.fromRawJson(String str)
-
factory
Properties
- analyticsLabel → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? analyticsLabel}) → AndroidFcmOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited