AndroidNotification class

Constructors

AndroidNotification({String? sound, String? clickAction, String? color, String? tag, String? bodyLocKey, List<String>? bodyLocArgs, String? titleLocKey, List<String>? titleLocArgs, String? channelId, bool? sticky, DateTime? eventTime, bool? localOnly, bool? defaultSound, bool? defaultVibrateTimings, bool? defaultLightSettings, List<String>? vibrateTimings, NotificationVisibility? visibility, String? notificationPriority, int? notificationCount, LightSettings? lightSettings})
AndroidNotification.fromJson(Map<String, dynamic> json)
factory
AndroidNotification.fromRawJson(String str)
factory

Properties

bodyLocArgs List<String>?
final
bodyLocKey String?
final
channelId String?
final
clickAction String?
final
color String?
final
defaultLightSettings bool?
final
defaultSound bool?
final
defaultVibrateTimings bool?
final
eventTime DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
lightSettings LightSettings?
final
localOnly bool?
final
notificationCount int?
final
notificationPriority String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sound String?
final
sticky bool?
final
tag String?
final
titleLocArgs List<String>?
final
titleLocKey String?
final
vibrateTimings List<String>?
final
visibility NotificationVisibility?
final

Methods

copyWith({String? sound, String? clickAction, String? color, String? tag, String? bodyLocKey, List<String>? bodyLocArgs, String? titleLocKey, List<String>? titleLocArgs, String? channelId, bool? sticky, DateTime? eventTime, bool? localOnly, bool? defaultSound, bool? defaultVibrateTimings, bool? defaultLightSettings, List<String>? vibrateTimings, NotificationVisibility? visibility, String? notificationPriority, int? notificationCount, LightSettings? lightSettings}) AndroidNotification
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited