Apns class

Constructors

Apns({ApnsHeaders? headers, Payload? payload, AndroidFcmOptions? fcmOptions})
Apns.fromJson(Map<String, dynamic> json)
factory
Apns.fromRawJson(String str)
factory

Properties

fcmOptions AndroidFcmOptions?
final
hashCode int
The hash code for this object.
no setterinherited
headers ApnsHeaders?
final
payload Payload?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ApnsHeaders? headers, Payload? payload, AndroidFcmOptions? fcmOptions}) Apns
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited