Color class

Constructors

Color({double? red, double? green, double? blue, int? alpha})
Color.fromJson(Map<String, dynamic> json)
factory
Color.fromRawJson(String str)
factory

Properties

alpha int?
final
blue double?
final
green double?
final
hashCode int
The hash code for this object.
no setterinherited
red double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? red, double? green, double? blue, int? alpha}) Color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited