LightSettings class

Constructors

LightSettings({Color? color, String? lightOnDuration, String? lightOffDuration})
LightSettings.fromJson(Map<String, dynamic> json)
factory
LightSettings.fromRawJson(String str)
factory

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
lightOffDuration String?
final
lightOnDuration String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? color, String? lightOnDuration, String? lightOffDuration}) LightSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited